@@ -1,5 +1,9 @@
 import pandas as pd
 from nltk.corpus import webtext
+import nltk
+
+nltk.download('webtext', silent=True)
+nltk.download('punkt', silent=True)
 
 
 def webtext_to_df(full_text: str) -> pd.DataFrame:
